import { usePlotContext } from './contexts/plotContext';
import { validateAxis } from './utils';
export function usePosition(config) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, 'x', 'y');
    const { x, y } = config;
    return {
        x: convertValue(x, plotWidth, xScale),
        y: convertValue(y, plotHeight, yScale),
    };
}
export function useRectanglePosition(config) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, 'x', 'y');
    const { x1, y1, x2, y2 } = config;
    return {
        x: convertMinValue(x1, x2, plotWidth, xScale),
        y: convertMinValue(y1, y2, plotHeight, yScale),
        width: convertDimensions(x1, x2, plotWidth, xScale),
        height: convertDimensions(y1, y2, plotHeight, yScale),
    };
}
export function useEllipsePosition(props) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, 'x', 'y');
    const { cx, cy, rx, ry } = props;
    return {
        cx: convertValue(cx, plotWidth, xScale),
        cy: convertValue(cy, plotHeight, yScale),
        rx: convertValueAbs(rx, plotWidth, xScale),
        ry: convertValueAbs(ry, plotHeight, yScale),
    };
}
function convertString(value, total) {
    return value.endsWith('%')
        ? (Number(value.slice(0, -1)) * total) / 100
        : Number(value);
}
function convertValue(value, total, scale) {
    if (scale === undefined)
        return 0;
    return typeof value === 'number' ? scale(value) : convertString(value, total);
}
function convertMinValue(value1, value2, total, scale) {
    if (scale === undefined)
        return 0;
    return Math.min(typeof value2 === 'number' ? scale(value2) : convertString(value2, total), typeof value1 === 'number' ? scale(value1) : convertString(value1, total));
}
function convertValueAbs(value, total, scale) {
    if (scale === undefined)
        return 0;
    return typeof value === 'number'
        ? Math.abs(scale(0) - scale(value))
        : convertString(value, total);
}
function convertDimensions(value1, value2, total, scale) {
    if (scale === undefined)
        return 0;
    return Math.abs((typeof value2 === 'number'
        ? scale(value2)
        : convertString(value2, total)) -
        (typeof value1 === 'number'
            ? scale(value1)
            : convertString(value1, total)));
}
export function usePointPosition(config) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, 'x', 'y');
    const points = config;
    return points
        .map((point) => `${convertValue(point.x, plotWidth, xScale)},${convertValue(point.y, plotHeight, yScale)}`)
        .join(' ');
}
//# sourceMappingURL=hooks.js.map