"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParallelAxis = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const plotContext_1 = require("../../contexts/plotContext");
const axis_1 = require("../../utils/axis");
const LinearAxis_1 = __importDefault(require("./LinearAxis"));
const LogAxis_1 = __importDefault(require("./LogAxis"));
function parallelPosition(position) {
    switch (position) {
        case 'bottom': {
            return 'top';
        }
        case 'top': {
            return 'bottom';
        }
        case 'left': {
            return 'right';
        }
        case 'right': {
            return 'left';
        }
        default: {
            throw new Error(`Unknown position ${position}`);
        }
    }
}
function ParallelAxis(props) {
    const { id, hidden = false, primaryTickLength = 5, tickPosition = 'outer', hiddenLine = false, hiddenTicks = false, ...otherProps } = props;
    const { axisContext, plotWidth, plotHeight } = (0, plotContext_1.usePlotContext)();
    const innerOffset = (0, axis_1.getInnerOffset)(hidden, hiddenTicks, tickPosition, primaryTickLength);
    // Don't display axis if parent id not in context
    const parentAxis = axisContext[id];
    if (!parentAxis)
        return null;
    // Get position opposite to parent axis
    const position = parallelPosition(parentAxis.position);
    // Renders according to position and scale
    const { type, scale, tickLabelFormat } = parentAxis;
    const childProps = {
        plotWidth,
        plotHeight,
        position,
        tickLabelFormat,
        displayPrimaryGridLines: false,
        hidden,
        primaryTickLength,
        tickPosition,
        hiddenLine,
        hiddenTicks,
        innerOffset,
        ...otherProps,
    };
    if (type === 'linear') {
        return ((0, jsx_runtime_1.jsx)(LinearAxis_1.default, { ...childProps, scale: scale }, void 0));
    }
    else {
        return ((0, jsx_runtime_1.jsx)(LogAxis_1.default, { ...childProps, scale: scale }, void 0));
    }
}
exports.ParallelAxis = ParallelAxis;
