"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LineSeries = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_shape_1 = require("d3-shape");
const react_1 = require("react");
const legendContext_1 = require("../contexts/legendContext");
const plotContext_1 = require("../contexts/plotContext");
const utils_1 = require("../utils");
const ErrorBars_1 = __importDefault(require("./ErrorBars"));
const ScatterSeries_1 = require("./ScatterSeries");
function LineSeries(props) {
    var _a;
    const [, legendDispatch] = (0, legendContext_1.useLegend)();
    const { colorScaler } = (0, plotContext_1.usePlotContext)();
    const [id] = (0, react_1.useState)(() => props.groupId || `series-${(0, utils_1.getNextId)()}`);
    const { lineStyle = {}, displayMarker = false, displayErrorBars = false, hidden, ...otherProps } = props;
    (0, react_1.useEffect)(() => {
        var _a, _b, _c;
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label: otherProps.label,
                    colorLine: ((_a = lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke) === null || _a === void 0 ? void 0 : _a.toString()) || colorScaler(id),
                    shape: {
                        color: ((_c = (_b = otherProps.markerStyle) === null || _b === void 0 ? void 0 : _b.fill) === null || _c === void 0 ? void 0 : _c.toString()) || colorScaler(id),
                        figure: otherProps.markerShape || 'circle',
                        hidden: !displayMarker,
                    },
                },
            });
        }
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [
        hidden,
        colorScaler,
        displayMarker,
        id,
        legendDispatch,
        lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke,
        otherProps.label,
        otherProps.markerShape,
        otherProps.markerStyle,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    const errorBarsProps = {
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        hidden: !displayErrorBars,
        style: props.errorBarsStyle,
        capStyle: props.errorBarsCapStyle,
        capSize: props.errorBarsCapSize,
    };
    return ((0, jsx_runtime_1.jsxs)("g", { children: [(0, jsx_runtime_1.jsx)(LineSeriesRender, { ...lineProps }, void 0), (0, jsx_runtime_1.jsx)(ErrorBars_1.default, { ...errorBarsProps }, void 0), (0, jsx_runtime_1.jsx)(ScatterSeries_1.ScatterSeries, { ...otherProps, hidden: !displayMarker, groupId: id }, void 0)] }, void 0));
}
exports.LineSeries = LineSeries;
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext, colorScaler } = (0, plotContext_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = (0, react_1.useMemo)(() => {
        if (xScale === undefined || yScale === undefined) {
            return null;
        }
        // Calculate line from D3
        const lineGenerator = (0, d3_shape_1.line)()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return (0, jsx_runtime_1.jsx)("path", { style: style, d: path, fill: "none" }, void 0);
}
